==> nextcloud-app-tasks-0.13.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/sq.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "E rëndësishme",
    "Today" : "Sot",
    "Week" : "Javë",
    "All" : "Krejt",
    "Current" : "E tanishmja",
    "Completed" : "Të plotësuara",
    "Tasks" : "Detyra",
    "New List" : "Listë e Re",
    "Cancel" : "Anuloje",
    "Save" : "Ruaje",
    "An empty name is not allowed." : "Nuk lejohet emër i zbrazët.",
    "Share with users or groups" : "Nda me përdoruesit ose grupet",
    "can edit" : "mund të modifikoni",
    "Edit" : "Përpunoni",
    "Download" : "Shkarkoje",
    "Delete" : "Fshije",
    "Unshare" : "Hiqe ndarjen",
    "Visibility of Smart Collections" : "Dukshmëri Koleksionesh të Mençura",
    "Hidden" : "I padukshëm",
    "Visible" : "I dukshëm",
    "Automatic" : "Automatike",
    "No errors" : "Nuk ka gabime",
    "Open your browser console for more details" : "Hapni panelin e komandimit të shfletuesit tuaj për më shumë detaje",
    "Change sort order" : "Ndryshoni rend renditjeje",
    "Start date" : "Datë nisjeje",
    "Due date" : "Datë përfundimi",
    "Last modified" : "Ndryshuar së fundmi",
    "Priority" : "Përparësi",
    "Alphabetically" : "Alfabetikisht",
    "Manually" : "Dorazi",
    "Task is completed" : "Detyra është e plotësuar",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Punë e Plotësuar","%n Punë të Plotësuara"],
    "Tomorrow" : "Nesër",
    "Set start date" : "Caktoni datë fillimi",
    "Set due date" : "Caktoni datë mbarimi",
    "All day" : "Gjithë ditën",
    "Task not found!" : "S’u gjet punë!",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/sq.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "E rëndësishme",
    "Today" : "Sot",
    "Week" : "Javë",
    "All" : "Krejt",
    "Current" : "E tanishmja",
    "Completed" : "Të plotësuara",
    "Tasks" : "Detyra",
    "Visibility of Smart Collections" : "Dukshmëri Koleksionesh të Mençura",
    "Hidden" : "I padukshëm",
    "Visible" : "I dukshëm",
    "Automatic" : "Automatike",
    "Share with users or groups" : "Nda me përdoruesit ose grupet",
    "Can edit" : "Can edit",
    "Edit" : "Përpunoni",
    "Copied" : "Kopjuar",
    "Export" : "Eksport",
    "Delete" : "Fshije",
    "Unshare" : "Hiqe ndarjen",
    "Save" : "Ruaje",
    "An empty name is not allowed." : "Nuk lejohet emër i zbrazët.",
    "Name" : "Emri",
    "Deleted" : "E fshirë",
    "Restore" : "Rikthe",
    "Delete permanently" : "Fshije përgjithmonë",
    "No errors" : "Nuk ka gabime",
    "Open your browser console for more details" : "Hapni panelin e komandimit të shfletuesit tuaj për më shumë detaje",
    "Change sort order" : "Ndryshoni rend renditjeje",
    "Start date" : "Datë nisjeje",
    "Due date" : "Datë përfundimi",
    "Last modified" : "Ndryshuar së fundmi",
    "Priority" : "Përparësi",
    "Alphabetically" : "Alfabetikisht",
    "Manually" : "Dorazi",
    "Task is completed" : "Detyra është e plotësuar",
    "Cancel" : "Anuloje",
    "Close" : "Mbylleni",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Punë e Plotësuar","%n Punë të Plotësuara"],
    "Tomorrow" : "Nesër",
    "New List" : "Listë e Re",
    "All day" : "Gjithë ditën",
    "Details" : "Detajet",
    "Select tags" : "Përzgjidh etiketat",
    "Notes" : "Shënime",
    "Reminders" : "Kujtues",
    "Repeat" : "Përsërite",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Canceled" : "Anuluar",
    "Task not found!" : "S’u gjet punë!",
    "Set start date" : "Caktoni datë fillimi",
    "Set due date" : "Caktoni datë mbarimi"
},
"nplurals=2; plural=(n != 1);");
